<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://fastcache.host.it/alessandropoletto
 * @since      1.0.0
 *
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @author     Alessandro Poletto <alessandro.poletto@host.it>
 */
class FASTCACHEHOST_HPublic {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	private $iconOk; // svg dell'icona OK
	private $iconKO; // svg dell'icona KO
	
	private $iconOkBig; // svg dell'icona OK
	private $iconKOBig; // svg dell'icona KO
	
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		add_action("wp_ajax_hstPurgeCache", array($this, "purgeCache"));
		add_action("wp_ajax_nopriv_hstPurgeCache", array($this, "purgeCache"));
		add_action("wp_ajax_testCache", array($this, "testCache"));
		add_action("wp_ajax_attivazionefastcache", array($this, "attivazionefastcache"));
		add_action("wp_ajax_updatetoken", array($this, "updatetoken"));
		add_action("wp_ajax_updatettl", array($this, "updatettl"));
		add_action('transition_post_status', array($this,'purgePostTransitionPostStatus'), 10, 3);
		
		$this->setIcons();
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/' . FASTCACHEHOST_HOST_PLUGINNAME . '-public.css', [], $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$p=plugin_dir_path( __FILE__ ) . 'js/' . FASTCACHEHOST_HOST_PLUGINNAME_PATH . '-public.js';
		$u=plugin_dir_url( __FILE__ ) . 'js/' . FASTCACHEHOST_HOST_PLUGINNAME_PATH . '-public.js';
		wp_enqueue_script( FASTCACHEHOST_HOST_PLUGINNAME, $u, array( 'jquery' ), filemtime($p), false );
		wp_localize_script(FASTCACHEHOST_HOST_PLUGINNAME, 'ajax_var', array(
			'url' => admin_url('admin-ajax.php'),
			'nonce' => wp_create_nonce('ajax-nonce')
		));
	}
	/**
	 * Append the button to the end of the content.
	 *
	 * @since    1.0.0
	 */
	public function append_the_button( $content ) {
		
		// Get our item ID
		$item_id = get_queried_object_id();
		
		// Get current item post type
		$current_post_type = get_post_type( $item_id );
		
		// Get our saved page ID, so we can make sure that this button isn't being shown there
		$saved_page_id = get_option( 'toptal_save_saved_page_id' );
		
		// Set default values for options that we are going to call below
		$post_types = array();
		$override = 0;
		
		// Get our options
		$options = get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS );
		if ( ! empty( $options['post-types'] ) ) {
			$post_types = $options['post-types'];
		}
		if ( ! empty( $options['toggle-content-override'] ) ) {
			$override = $options['toggle-content-override'];
		}
		
		// Let's check if all conditions are ok
		if ( $override == 1 && ! empty( $post_types ) && ! is_page( $saved_page_id ) && in_array( $current_post_type, $post_types ) ) {
			
			// Append the button
			$custom_content = '';
			ob_start();
			// echo $this->show_save_button();
			$custom_content .= ob_get_contents();
			ob_end_clean();
			$content = $content . $custom_content;
			
		}
		
		return $content;
		
	}
	public function send_headers()
	{
		global $post;
		$enable=0;
		if(!isset($post->post_type)) {
			$ttl=86400;
		} else {
			$pt       = $post->post_type;
			
			$settings = get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS );
			$enable=0;
			if(isset($settings['activate'])) {
				$enable = $settings['activate'];
			}
			$token="";
			if(isset($settings['text-token'])) {
				$token = $settings['text-token'];
			}
			if (
				isset( $settings['ttl-post-types'][ $pt ] )
				&& trim( $settings['ttl-post-types'][ $pt ] ) != ""
				&& $settings['ttl-post-types'][ $pt ] > 0 ) {
				// echo "trovato  post type ".$pt . " set ttl: " . $settings['ttl-post-types'][$pt] . "<br>"   ;
				$ttl = $settings['ttl-post-types'][ $pt ];
			} else if (
				isset( $settings['default-ttl'] )
				&& trim( $settings['default-ttl'] ) != ""
				&& $settings['default-ttl'] > 0
			) {
				// echo "trovato default ttl: " . $settings['default-ttl'] . "<br>"   ;
				$ttl = $settings['default-ttl'];
			} else {
				$ttl = 86400;
			}
		}
		if(is_feed()) {
			$ttl=60;
		}
		if ($enable==1 && trim($token)!="") {
			if (is_user_logged_in()) {
				Header('X-HST-CACHE-Enabled: false:User is logged in', true);
				$ttl = 0;
			} else {
				Header('X-HST-CACHE-Enabled: true', true);
			}
			Header('X-HST-CACHE-ttl: ' . $ttl, true);
			//			if ($this->debug) {
			//				Header('X-HST-CACHE-Debug: true', true);
			//			}
		 } else {
			Header('X-HST-CACHE-Enabled: false', true);
		}
	}
	public function attivazionefastcache() {
		
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash ( $_POST['nonce'] ) ) , 'ajax-nonce' ) ) {
			die ( 'Alcuni controlli di sicurezza non sono andati a buon fine, consigliamo di contattare l\'assistenza del plugin!');
		}
		
		$vars      =   get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS);
		if(!is_array($vars) ) { $vars=[];}
		if(sanitize_text_field(wp_unslash($_POST['data']['activate'])) !== null) {
			if(sanitize_text_field(wp_unslash($_POST['data']['activate']))==1 || sanitize_text_field(wp_unslash($_POST['data']['activate']))==0) {
				$datas=sanitize_post($_POST['data']);
				update_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS , array_merge( $vars, $datas ) );
			}
		}
		if(isset($_POST['data']['activatelog'])) {
			if(sanitize_text_field(wp_unslash($_POST['data']['activatelog']))==1 || sanitize_text_field(wp_unslash($_POST['data']['activatelog']))==0) {
				$datas=sanitize_post($_POST['data']);
				update_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS, array_merge( $vars, $datas ) );
			}
		}
		// $vars      =   get_option( FASTCACHEHOST_HOST_PLUGINNAME . '-settings');
		exit();
	}
	public function updatetoken() {
		
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash ( $_POST['nonce'] ) ) , 'ajax-nonce' ) ) {
			die ( 'Alcuni controlli di sicurezza non sono andati a buon fine, consigliamo di contattare l\'assistenza del plugin!');
		}
		$vars      =   get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS );
		if($_POST['data']['newtoken']==1 || $_POST['data']['newtoken']!="") {
			$vars['text-token']=sanitize_text_field($_POST['data']['newtoken']);
			update_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS , $vars  );
			echo"OK";
			exit();
		}
		echo "KO";
		exit();
	}
	public function updatettl() {
		
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash ( $_POST['nonce'] ) ) , 'ajax-nonce' ) ) {
			die ( 'Alcuni controlli di sicurezza non sono andati a buon fine, consigliamo di contattare l\'assistenza del plugin!');
		}
		$vars      =    get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS );
		$mod       =    0;
		$noInt     =    0;
		if(!isset($_POST['data']) || !is_array($_POST['data']) || empty($_POST['data'])) {
			return;
		}
		$datas=sanitize_post($_POST['data']);
		foreach($datas as $chiave=>$valore) {
			$chiave = sanitize_text_field($chiave);
			$valore = sanitize_text_field($valore);
			if($valore=="") { $valore=86400;}
			if($chiave=="filter") {continue;}
			if($chiave=="default") {
				if($vars['default-ttl']!=$valore) {
					$mod=1;
				}
				$vars['default-ttl']=$valore;
			} else {
				if ( $vars['ttl-post-types'][ $chiave ] != $valore ) {
					$mod = 1;
				}
				$vars['ttl-post-types'][ $chiave ] = $valore;
			}
			if(!is_numeric($valore)) {
				$noint=$chiave;
			}
		}
		if($noint!=0) {
			echo wp_kses("Il Post-Type: " . strtoupper($noint) . " non è un numero intero", FASTCACHEHOST_ALLOWEDHTML);
			exit();
		}
		if($mod==0) {
			echo wp_kses("OK", FASTCACHEHOST_ALLOWEDHTML);
			exit();
		}
		update_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS , $vars  );
		echo wp_kses("OK", FASTCACHEHOST_ALLOWEDHTML);
		exit();
	}
	public function testCache() {
		
		if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash ( $_POST['nonce'] ) ) , 'ajax-nonce' ) ) {
			die ( 'Alcuni controlli di sicurezza non sono andati a buon fine, consigliamo di contattare l\'assistenza del plugin!');
		}
		$token      =   get_option( FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS )['text-token'];
		$method="exact";
		$url        =   FASTCACHEHOST_HOST_ENDPOINTCACHE . "testcache" ;
		$params =array(
			'X-HST-CACHE-PurgeKey'      => $token,
			'host'                      => FASTCACHEHOST_HOSTNAME,
			'X-HST-CACHE-Purge-Method'  => $method
		);
		$response = wp_remote_request($url, array(
			'method'                    => 'PURGE',
			'headers'                   => $params,
			'sslverify' => false,
		));

		if(is_wp_error($response)) {
			$htmlReport="Errore di comunicazione";
		} else {
			$retArr = $this->createReportTest($response);
			$htmlReport = $this->createHtmlReportTest($retArr);
		}
		echo wp_kses($htmlReport, FASTCACHEHOST_ALLOWEDHTML);
		exit();
	}
	private function createReportTest($response) {
		// print_r($response);
		$messaggiBodyArr                    = json_decode( $response['body'], true );
		$report                             = [];
		$report['cdn']                      = "ko";
		$report['comandi']                  = "ko";
		$report['cache-ita']['servercount'] = 0;
		$report['cache-ita']['ko']          = 0;
		$report['cache-ita']['ok']          = 0;
		$report['cache-ita']['unauth']      = 0;
		$report['cache-int']['servercount'] = 0;
		$report['cache-int']['ko']          = 0;
		$report['cache-int']['ok']          = 0;
		$report['cache-int']['unauth']      = 0;
		$errore                             = 0;
		if (
			isset( $response['response']['code'] )
			&& $response['response']['code'] == 200
		) {
			$report['cdn'] = "ok";
		} else {
			$errore ++;
		}
		
		if (
			isset( $messaggiBodyArr['done'] )
			&& $messaggiBodyArr['done'] == 1
		) {
			// file_put_contents(dirname(__FILE__) . "/done.log",$messaggiBodyArr['done']);
			$report['comandi'] = "ok";
		} else {
			$errore ++;
		}
		if ( isset( $messaggiBodyArr['nodes'] ) ) {
			foreach ( $messaggiBodyArr['nodes'] as $server => $messaggio ) {
				if ( str_contains( strtolower( $server ), "cache-ita" ) ) {
					$report['cache-ita']['servercount'] ++;
					if ( $messaggio == "404" ) {
						$report['cache-ita']['ko'] ++;
						$errore ++;
						
					} else if ( $messaggio == "405" ) {
						$report['cache-ita']['unauth'] ++;
						$errore ++;
						
					} else {
						$report['cache-ita']['ok'] ++;
					}
				}
				if ( str_contains( strtolower( $server ), "cache-int" ) ) {
					$report['cache-int']['servercount'] ++;
					
					if ( $messaggio == "404" ) {
						$report['cache-int']['ko'] ++;
						$errore ++;
					} else if ( $messaggio == "405" ) {
						$report['cache-int']['unauth'] ++;
						$errore ++;
					} else {
						$report['cache-int']['ok'] ++;
					}
				}
				if ( $messaggio != "200" && $messaggio != "404" ) {
					$errore = 1;
				}
			}
			
		}
		return array("report"=>$report,"errore"=>$errore);
	}
	private function createHtmlReportTest($arr) {
		$report     =   $arr['report'];
		$errore     =   $arr['errore'];
		$html       =   $this->htmlBlockGeneralStatus($errore);
		$html       .=  $this->htmlBlockFunzionamentoGlobale($report);
		$html       .=  $this->htmlBlockCacheSections($report);
		return $html;
	}
	private function htmlBlockCacheSections($report) {
		$html = "<div class=\"peer-has-[span.clicked]:grid hidden  grid-cols-4 gapx-4 w-full\">";
		$sezioni=array(
			"cache-ita"=>['label'=>'CDN Ita'],
			"cache-int"=>['label'=>'CDN Int']
		);
		$servizi=[
			"servercount"=>"Server",
			"ko"=>"KO",
			"ok"=>"OK",
			"unauth"=>"UnAuth"
		];
		
		foreach($sezioni as $sezione=>$datas ) {
			if($report[$sezione]['servercount']==0) {
				continue;
			}
			$label = $datas['label'];
			$html .="<div class='peer-has-[span.clicked]:grid hidden col-span-4 p-2 bg-gray-200  mt-4 '>" . $label .  "</div>";
			foreach($servizi as $k=>$v) {
				$html .="<div class='h-8 justify-around content-around bg-gray-100 text-gray-800  my-4'>" . $v .  "</div>";
			}
			if ( isset( $report[$sezione]['servercount'] ) && $report[$sezione]['servercount'] > 0 ) {
				$html .= $this->createIcon( "ok",  $report[$sezione]['servercount'] );
			} else {
				$html .= $this->createIcon( "ko",  $report[$sezione]['servercount'] );
			}
			if ( isset( $report[$sezione]['ko'] ) && $report[$sezione]['ko'] > 0 ) {
				$html .= $this->createIcon( "ko",  $report[$sezione]['ko'] );
			} else {
				$html .= $this->createIcon( "ok",  $report[$sezione]['ko'] );
			}
			if ( isset( $report[$sezione]['ok'] ) && $report[$sezione]['ok'] > 0 ) {
				$html .= $this->createIcon( "ok",  $report[$sezione]['ok'] );
			} else {
				$html .= $this->createIcon( "ko",   $report[$sezione]['ok'] );
			}
			if ( isset( $report[$sezione]['unauth'] ) && $report[$sezione]['unauth'] > 0 ) {
				$html .= $this->createIcon( "ko",  $report[$sezione]['unauth'] );
			} else {
				$html .= $this->createIcon( "ok",  $report[$sezione]['unauth'] );
			}
		}
		$html .= "</div>";
		return $html;
	}
	private function htmlBlockFunzionamentoGlobale($report) {
		$html       =  "<div class='peer-has-[span.clicked]:flex hidden  w-full p-2 bg-gray-200 mt-4'>Funzionamento Globale</div>";
		
		$html       .=  "<div class=\"peer-has-[span.clicked]:grid hidden grid grid-cols-2 gapx-4 w-full my-8\"> ";
		if(isset($report['cdn']) && $report['cdn']=="ok") {
			$html   .=  $this->createIcon("ok","CDN");
		} else {
			$html   .=  $this->createIcon("ko","CDN");
		}
		if(isset($report['comandi']) && $report['comandi']=="ok") {
			$html   .=  $this->createIcon("ok","Comandi");
		} else {
			$html   .=  $this->createIcon("ko","Comandi");
		}
		$html .= "</div>";
		
		return $html;
	}
	private function htmlBlockGeneralStatus($errore) {
		$sn         =   sanitize_text_field($_SERVER['SERVER_NAME']);
		$html       =   "<div class='peer  w-full p-2 bg-gray-200 mt-4'>Controllo indirizzi</div>";
		
		$html       .=   "<div class=\"w-full p-2\">Hostname <span class='font-bold'>" . $sn . "</span></div>";
		$html       .=   "<div class=\"w-full p-2\">Ip Server <span class='font-bold'>" . $this->idServer() . "</span></div>";
		$html       .=   "<div class=\"w-full p-2\">Ip da dns <span class='font-bold'>" . $this->idDns($sn) . "</span></div>";
		$html       .=   "<div class='peer  w-full p-2 bg-gray-200 mt-4'>CDN Check<span id='opendettaglio'  class='text-[10px] text-blue-500 underline float-right'>Dettaglio</span></div>";
		$msgOk      =   "La CDN è correttamente configurata";
		$msgErrore  =   "Rilevati errore con la configurazione della CDN<br>Controlla tutti i parametri<br><br>Se il problema persiste mettersi in contatto con lo staff di assistenza di Host.it allegando lo screenshot di questa pagina dopo aver premuto il link \"dettaglio\"";
		if($errore==0) {
			$html   .=  $this->createIcon("ok",$msgOk, "w-full grid grid-cols-[100px_1fr] text-center py-4 ");
		} else {
			$html   .=  $this->createIcon("ko",$msgErrore, "w-full grid grid-cols-[100px_1fr] text-left py-4 ");
		}
		return $html;
	}
	private function idServer() {
		
		if (function_exists('filter_var') && filter_var($_SERVER['SERVER_ADDR'], FILTER_VALIDATE_IP, array('flags' => FILTER_FLAG_IPV4, FILTER_FLAG_NO_PRIV_RANGE, FILTER_FLAG_NO_RES_RANGE))){
			$ip = filter_var($_SERVER['SERVER_ADDR'],FILTER_VALIDATE_IP, array('flags' => FILTER_FLAG_IPV4, FILTER_FLAG_NO_PRIV_RANGE, FILTER_FLAG_NO_RES_RANGE));
		}
		
		$ret=wp_remote_get("https://mioip.host.it/ip.php", array('timeout' => 10));
		if(!is_wp_error($ret)) {
			if(is_array($ret) && isset($ret['body']) && trim($ip)!=trim($ret['body'])) {
				$ip .= " / " . $ret['body'];
			}
		}
		return $ip;
	}
	
	
	private function idDns($sn) {
		$ip = gethostbyname($sn);
		return $ip;
	}
	private function createIcon($status,$label, $class="") {
		if($class!="") {$class=" class=\"" . $class . "\"";}
		$html ="<div " . $class . ">";
		
		if($class!="") {
			if ( $status == "ok" ) {
				$html .= $this->iconOkBig;
			} else {
				$html .= $this->iconKOBig;
			}
		} else {
			if($status=="ok") {
				$html   .=  $this->iconOk;
			} else {
				$html   .=  $this->iconKO;
			}
		}
		$html   .=  "<span class='label content-center'>$label</span>";
		$html   .=  "</div>";
		return $html;
	}
	
	public function purgePostTransitionPostStatus($new_status, $old_status, $post) {
		if ($old_status === 'future' && $new_status === 'publish') {
			// Ottieni l'URL della pagina
			$post_url = get_permalink($post->ID);
			$pu = wp_parse_url(sanitize_text_field($post_url));
			$path=$pu['path'];
			$pathq="";
			$settings = get_option(FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS);
			if (!isset($settings['text-token']) || trim($settings['text-token']) == "") {
				echo "KO";
				exit();
			}
			$token = $settings['text-token'];
			$url = FASTCACHEHOST_HOST_ENDPOINTCACHE . ltrim($path,'/') . $pathq;
			$method = "exact";
			$this->execute_purge($token,$url,$method);
		}
		
	}
	private function setIcons() {
		$this->iconOk="<span class=\"inline-flex items-center justify-center w-6 h-6 me-2 text-sm font-semibold text-white bg-green-500 rounded-full okicon\">";
			$this->iconOk.="<svg class=\"w-4 h-4\"  fill=\"none\" viewBox=\"0 0 16 12\" >";
			$this->iconOk.="<path stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\"2\" d=\"M1 5.917 5.724 10.5 15 1.5\"/>";
			$this->iconOk.="</svg>";
		$this->iconOk.="</span>";
		
		$this->iconKO="<span class=\"inline-flex items-center justify-center w-6 h-6 me-2 text-sm font-semibold text-white bg-red-500 rounded-full koicon\">";
		   $this->iconKO.="<svg class=\"w-4 h-4\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" >";
				$this->iconKO.="<path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M6 18 18 6M6 6l12 12\" />";
			$this->iconKO.="</svg>";
		$this->iconKO.="</span>";

		$this->iconOkBig="<span class=\"inline-flex justify-self-center items-center justify-center w-8 h-8 me-2 mt-2  text-sm font-semibold text-white bg-green-500 rounded-full\">";
			$this->iconOkBig.="<svg class=\"w-8 h-8\"  fill=\"none\" viewBox=\"0 0 16 12\" >";
			$this->iconOkBig.="<path stroke=\"currentColor\" stroke-linecap=\"round\" stroke-linejoin=\"round\" stroke-width=\"2\" d=\"M1 5.917 5.724 10.5 15 1.5\"/>";
			$this->iconOkBig.="</svg>";
		$this->iconOkBig.="</span>";

		$this->iconKOBig="<span class=\"inline-flex justify-self-center items-center justify-center w-8 h-8 me-2 mt-2 text-sm font-semibold text-white bg-red-500 rounded-full\">";
		   $this->iconKOBig.="<svg class=\"w-8 h-8\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" >";
				$this->iconKOBig.="<path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M6 18 18 6M6 6l12 12\" />";
			$this->iconKOBig.="</svg>";
	   $this->iconKOBig.="</span>";
	}
	public function purgeCache() {
		$logger = new \FASTCACHEHOST_HCommon\FASTCACHEHOST_HCommon();
		if (!isset($_POST['nonce']) || !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'ajax-nonce')) {
			die ('Alcuni controlli di sicurezza non sono andati a buon fine, consigliamo di contattare l\'assistenza del plugin!');
		}
		$settings = get_option(FASTCACHEHOST_HOST_PLUGINNAME_SETTINGS);
		if (!isset($settings['text-token']) || trim($settings['text-token']) == "") {
			echo "KO";
			exit();
		}
		$token = $settings['text-token'];
		if (isset($_POST) && isset($_POST['param']) && trim($_POST['param']) != "") {
			$param = sanitize_text_field($_POST['param']);
		} else {
			exit();
		}
		$method = "regexp";
		$pathq = "";
		switch ($param) {
			case "this":
				if (isset($_POST) && isset($_POST['loc']) && trim($_POST['loc']) != "") {
					$pu = wp_parse_url(sanitize_text_field($_POST['loc']));
					$path = ".*";
					if (!empty($pu) && isset($pu['path']) && trim($pu['path']) != "") {
						$path = $pu['path'];
						if ($path == "/") {
							$path = "";
						}
					}
					if (!empty($pu) && isset($pu['query']) && trim($pu['query']) != "") {
						if (isset($pu['query']) && $pu['query'] != "") {
							$pathq = "?=" . $pu['query'];
						}
					}
				}
				$url = FASTCACHEHOST_HOST_ENDPOINTCACHE . $path . $pathq;
				$method = "exact";
				break;
			case "all":
				$url = FASTCACHEHOST_HOST_ENDPOINTCACHE . ".*";
				$method = "regexp";
				break;
			case "homepage":
				$url = FASTCACHEHOST_HOST_ENDPOINTCACHE;
				$method = "exact";
				break;
			default:
				$url = FASTCACHEHOST_HOST_ENDPOINTCACHE . ".*";
				$method = "regexp";
				break;
		}
		$this->execute_purge($token,$url,$method);
	}
	private function execute_purge($token, $url, $method ) {
		$logger = new \FASTCACHEHOST_HCommon\FASTCACHEHOST_HCommon();
		
		$params =array(
			'X-HST-CACHE-PurgeKey'      => $token,
			'host'                      => FASTCACHEHOST_HOSTNAME,
			'X-HST-CACHE-Purge-Method'  => $method
		);
		$response = wp_remote_request($url, array(
			'method'                    => 'PURGE',
			'headers'                   => $params,
			'sslverify' => false,
		
		));
		$errore=0;
		if(is_wp_error($response)) {
			$logger->fr("PURGE: ERROR");
			$logger->fr("Host:" . FASTCACHEHOST_HOSTNAME);
			$logger->fr("Method:" . $method);
			$logger->fr("Token:" . $token);
			
			$errore=1;
		} else {
			$logger->fr("PURGE: ". $url . " Method: " . $method." noadm - retcode:" .$response['response']['code']);
			usleep(100000);
			$messaggiBodyArr                = json_decode($response['body'],true);
			if(isset($messaggiBodyArr['nodes'])) {
				foreach($messaggiBodyArr['nodes'] as $messaggio) {
					if($messaggio!="200" && $messaggio != "404") {
						$errore=1;
					}
				}
				
			}
		}
		/**
		 * classi in "inline style" e non in tailwind perchè in frontend non abbiamo tailwind
		 */
		if($errore!=0) {
$html ="<div style=\"padding:1rem; background-color:#FFDCDCFF; border-color: #E5E7EBFF; border-width:1px; z-index:5000; right:3.5rem; position:fixed; top:7rem; box-shadow: 0 0 #0000, 0 0 #0000, 0 0 #0000, 0 0 #0000, 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);\" class=\"\">";
	$html .="<div style=\"padding:1rem; font-size: 0.875rem; line-height:1.25rem; color:#AD3333FF; border-radius: 0.5rem; display: flex; flex-direction: column;\" class=\" \" role=\"alert\">";
	  $html .="<span style=\"font-weight: 500; width:100%; margin-bottom:0.5rem;\" >Attenzione!</span> è stato rilevato un problema. In caso l'errore persistesse contattate l'assistenza di HOST.it";
	$html .="</div>";
$html .="</div>";

			echo "Attenzione, è stato rilevato un problema. In caso l'errore persistesse contattate l'assistenza di HOST.it";
		} else {
$html ="<div style=\"padding:1rem; background-color:#DCFFDCFF; border-color: #E5E7EBFF; border-width:1px; z-index:5000; right:3.5rem; position:fixed; top:7rem;box-shadow: 0 0 #0000, 0 0 #0000, 0 0 #0000, 0 0 #0000, 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);\" class=\"  \">";
	$html .="<div style=\"padding:1rem;  font-size: 0.875rem; line-height:1.25rem;  color:#33AD33FF; border-radius: 0.5rem; display: flex; flex-direction: column; \" class=\"\" role=\"alert\">";
	  $html .="<span style=\"font-weight: 500; width:100%; margin-bottom:0.5rem;\" >Success!</span> Pulizia delle cache effettuata";
	$html .="</div>";
$html .="</div>";
		}
		echo wp_kses($html,FASTCACHEHOST_ALLOWEDHTML);
		exit();
	}
	
}
